import { NextFunction, Request, Response } from "express";

import { oauth2 } from "../../utils/auth";

const refreshToken = () => async (
  req: Request,
  res: Response,
  next: NextFunction
) => {
  if (req.session && req.session.user) {
    try {
      let accessToken = oauth2().accessToken.create(req.session.user.token);
      if (
        accessToken.expired(
          Number(process.env.AUTH_TOKEN_EXPIRATION_WINDOW_IN_SECONDS)
        )
      ) {
        req.session.user.token = await accessToken
          .refresh()
          .then((accessToken) => accessToken.token);
      }
    } catch (error) {
      console.log("Error refreshing access token: ", error.message);
    }
  }
  next();
};

export default refreshToken;
